@@ -1,12 +1,12 @@
-from .config import HEADERS
 from .attrs import asdict, dataclass, sdataclass, field, fields, freeze
-from .utils import from_dict, from_list
+from .utils import from_dict, from_list, cachedmethod
+from .defaults import Defaults
+from .config import HEADERS
 from .config import Config
 from .prop import Prop
 from .dapodik import BaseDapodik
 
 __all__ = [
-    "HEADERS",
     "asdict",
     "dataclass",
     "sdataclass",
@@ -15,6 +15,9 @@ __all__ = [
     "freeze",
     "from_dict",
     "from_list",
+    "cachedmethod",
+    "Defaults",
+    "HEADERS",
     "Config",
     "Prop",
     "BaseDapodik",
