@@ -5,7 +5,9 @@ from dapodik.base import BaseDapodik, HEADERS, Config
 from dapodik.utils.decorator import lazy
 
 from . import BaseAuth
+from . import BaseRest
 from . import BaseSekolah
+from . import BasePesertaDidik
 from . import BaseValidasi
 
 
@@ -26,12 +28,24 @@ class Dapodik(BaseDapodik):
         self.daftar_pengguna = self.auth.login(
             username, password, rememberme, semester_id, pengguna
         )
+        if self.daftar_pengguna:
+            self.logger.info(f"Berhasil login {username}")
 
     @property  # type: ignore
     @lazy
     def auth(self) -> BaseAuth:
         return BaseAuth(self.config)
 
+    @property  # type: ignore
+    @lazy
+    def peserta_didik(self) -> BasePesertaDidik:
+        return BasePesertaDidik(self.config)
+
+    @property  # type: ignore
+    @lazy
+    def rest(self) -> BaseRest:
+        return BaseRest(self.config)
+
     @property  # type: ignore
     @lazy
     def sekolah(self) -> BaseSekolah:
