@@ -2,10 +2,12 @@ from .peserta_didik_baru import PesertaDidikBaru
 from .peserta_didik_longitudinal import PesertaDidikLongitudinal
 from .peserta_didik import PesertaDidik
 from .registrasi_peserta_didik import RegistrasiPesertaDidik
+from .base import BasePesertaDidik
 
 __all__ = [
     "PesertaDidikBaru",
     "PesertaDidikLongitudinal",
     "PesertaDidik",
     "RegistrasiPesertaDidik",
+    "BasePesertaDidik",
 ]
