@@ -1,16 +1,8 @@
-import attr
-from dapodik import DapodikObject, Sekolah, JenisPendaftaran, TahunAjaran
-from dapodik.utils.decorator import set_meta
+from dapodik.base import dataclass
 
 
-@set_meta(
-    "pdb_id",
-    sekolah=Sekolah,
-    tahun_ajaran=TahunAjaran,
-    jenis_pendaftaran=JenisPendaftaran,
-)
-@attr.dataclass
-class PesertaDidikBaru(DapodikObject):
+@dataclass
+class PesertaDidikBaru:
     sekolah_id: str
     nama_pd: str
     jenis_kelamin: str
