@@ -1,26 +1,10 @@
-import attr
 from typing import Optional
-from dapodik import (
-    DapodikObject,
-    PesertaDidik,
-    Sekolah,
-    JenisPendaftaran,
-    JenisKeluar,
-    JurusanSp,
-)
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta(
-    "registrasi_id",
-    peserta_didik=PesertaDidik,
-    sekolah=Sekolah,
-    jurusan_sp=JurusanSp,
-    jenis_pendaftaran=JenisPendaftaran,
-    jenis_keluar=JenisKeluar,
-)
-@attr.dataclass
-class RegistrasiPesertaDidik(DapodikObject):
+@dataclass
+class RegistrasiPesertaDidik:
     peserta_didik_id: str
     sekolah_id: str
     tanggal_masuk_sekolah: str
