@@ -11,6 +11,7 @@ from .gmd import Gmd
 from .jadwal_paud import JadwalPaud
 from .jenis_gugus import JenisGugus
 from .jenis_hapus_buku import JenisHapusBuku
+from .jenis_hobby import JenisHobby
 from .jenis_keluar import JenisKeluar
 from .jenis_lk import JenisLk
 from .jenis_pendaftaran import JenisPendaftaran
@@ -44,6 +45,7 @@ from .sync_log import SyncLog
 from .tahun_ajaran import TahunAjaran
 from .tingkat_pendidikan import TingkatPendidikan
 from .waktu_penyelenggaraan import WaktuPenyelenggaraan
+from .base import BaseRest
 
 __all__ = [
     "Agama",
@@ -59,6 +61,7 @@ __all__ = [
     "JadwalPaud",
     "JenisGugus",
     "JenisHapusBuku",
+    "JenisHobby",
     "JenisKeluar",
     "JenisLk",
     "JenisPendaftaran",
@@ -92,4 +95,5 @@ __all__ = [
     "TahunAjaran",
     "TingkatPendidikan",
     "WaktuPenyelenggaraan",
+    "BaseRest",
 ]
