@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("id_bank")
-@attr.dataclass(frozen=True)
-class Bank(DapodikObject):
+@dataclass(frozen=True)
+class Bank:
     id_bank: str
     nm_bank: str
     create_date: datetime
