@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("jadwal_id")
-@attr.dataclass(frozen=True)
-class JadwalPaud(DapodikObject):
+@dataclass(frozen=True)
+class JadwalPaud:
     jadwal_id: str
     nama: str
     kesehatan: str
