@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("id_jenis_lk")
-@attr.dataclass(frozen=True)
-class JenisLk(DapodikObject):
+@dataclass(frozen=True)
+class JenisLk:
     id_jenis_lk: str
     nm_jenis_lk: str
     ket_jenis_lk: Optional[str]
