@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("jenis_ptk_id")
-@attr.dataclass(frozen=True)
-class JenisPtk(DapodikObject):
+@dataclass(frozen=True)
+class JenisPtk:
     jenis_ptk_id: str
     jenis_ptk: str
     guru_kelas: str
