@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("kebutuhan_khusus_id")
-@attr.dataclass(frozen=True)
-class KebutuhanKhusus(DapodikObject):
+@dataclass(frozen=True)
+class KebutuhanKhusus:
     kebutuhan_khusus_id: int
     kebutuhan_khusus: str
     kk_a: str
