@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime, date
 from typing import Optional
-from dapodik import DapodikObject, Jurusan
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("kurikulum_id", jurusan=Jurusan)
-@attr.dataclass(frozen=True)
-class Kurikulum(DapodikObject):
+@dataclass(frozen=True)
+class Kurikulum:
     kurikulum_id: int
     nama_kurikulum: str
     mulai_berlaku: date
