@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject, Jurusan
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("mata_pelajaran_id", jurusan=Jurusan)
-@attr.dataclass(frozen=True)
-class MataPelajaran(DapodikObject):
+@dataclass(frozen=True)
+class MataPelajaran:
     mata_pelajaran_id: int
     nama: str
     pilihan_sekolah: str
