@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("kode_wilayah")
-@attr.dataclass(frozen=True)
-class MstWilayah(DapodikObject):
+@dataclass(frozen=True)
+class MstWilayah:
     kode_wilayah: str
     nama: str
     id_level_wilayah: int
