@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("pekerjaan_id")
-@attr.dataclass(frozen=True)
-class Pekerjaan(DapodikObject):
+@dataclass(frozen=True)
+class Pekerjaan:
     pekerjaan_id: int
     nama: str
     a_wirausaha: str
