@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("penghasilan_id")
-@attr.dataclass(frozen=True)
-class Penghasilan(DapodikObject):
+@dataclass(frozen=True)
+class Penghasilan:
     penghasilan_id: int
     nama: str
     batas_bawah: int
