@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("kepemilikan_sarpras_id")
-@attr.dataclass(frozen=True)
-class StatusKepemilikanSarpras(DapodikObject):
+@dataclass(frozen=True)
+class StatusKepemilikanSarpras:
     kepemilikan_sarpras_id: str
     nama: str
     create_date: datetime
