@@ -1,12 +1,10 @@
-import attr
 from datetime import datetime
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("sync_log_id")
-@attr.dataclass(frozen=True)
-class SyncLog(DapodikObject):
+@dataclass(frozen=True)
+class SyncLog:
     id_instalasi: str
     begin_sync: datetime
     end_sync: datetime
