@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime, date
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("tahun_ajaran_id")
-@attr.dataclass(frozen=True)
-class TahunAjaran(DapodikObject):
+@dataclass(frozen=True)
+class TahunAjaran:
     tahun_ajaran_id: str
     nama: str
     periode_aktif: str
