@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("tingkat_pendidikan_id")
-@attr.dataclass(frozen=True)
-class TingkatPendidikan(DapodikObject):
+@dataclass(frozen=True)
+class TingkatPendidikan:
     tingkat_pendidikan_id: str
     kode: str
     nama: str
