@@ -1,12 +1,10 @@
-import attr
 from datetime import datetime
-from dapodik import DapodikObject, Sekolah, Akreditasi, LembagaPengangkat
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("akred_sp_id", akred_sp=Akreditasi, sekolah=Sekolah, la=LembagaPengangkat)
-@attr.dataclass
-class AkreditasiSp(DapodikObject):
+@dataclass
+class AkreditasiSp:
     akred_sp_id: str
     sekolah_id: str
     akred_sp_sk: str
