@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime
 from typing import Optional
-from dapodik import DapodikObject, Sekolah, SumberDanaSekolah
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("blockgrant_id", sekolah=Sekolah, sumber_dana=SumberDanaSekolah)
-@attr.dataclass
-class BlockGrant(DapodikObject):
+@dataclass
+class BlockGrant:
     blockgrant_id: str
     sekolah_id: str
     nama: str
@@ -26,8 +24,3 @@ class BlockGrant(DapodikObject):
     sekolah_id_str: str
     jenis_bantuan_id_str: str
     sumber_dana_id_str: str
-
-    @property
-    def jenis_bantuan(self):
-        # TODO API
-        return self.jenis_bantuan_id
