@@ -1,12 +1,10 @@
-import attr
 from datetime import datetime
-from dapodik import DapodikObject, Sekolah
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("id_panitia", sekolah=Sekolah)
-@attr.dataclass
-class Kepanitiaan(DapodikObject):
+@dataclass
+class Kepanitiaan:
     id_panitia: str
     sekolah_id: str
     id_jns_panitia: int
@@ -29,8 +27,3 @@ class Kepanitiaan(DapodikObject):
     updater_id: str
     sekolah_id_str: str
     id_jns_panitia_str: str
-
-    @property
-    def jns_panitia(self):
-        # TODO API
-        return self.id_jns_panitia
