@@ -1,13 +1,11 @@
-import attr
 from datetime import datetime, date
 from typing import Optional
-from dapodik import DapodikObject, TahunAjaran
-from dapodik.utils.decorator import set_meta
+
+from dapodik.base import dataclass
 
 
-@set_meta("semester_id", tahun_ajaran=TahunAjaran)
-@attr.dataclass
-class Semester(DapodikObject):
+@dataclass
+class Semester:
     semester_id: str
     tahun_ajaran_id: str
     nama: str
